      SUBROUTINE VADDK(VECR, NVEC, CONST)
C
C***********************************************************************
C
C   NAME- VADDK
C
C   LANGUAGE- FORTRAN 77     TYPE- SUBROUTINE  COMPUTER- CRAY    
C
C   VERSION- 1.0   DATE- 07/13/89   PROGRAMMER- S.SWEETLAND (SMSRC)
C   VERSION- 3.0   DATE- 05/10/96   PROGRAMMER- A.POZDNYAK (FDC)   
C     FOR REHOSTING TO THE CRAY, CHANGED ALL I*4 DECLARATIONS TO
C      INTEGER AND ALL R*4 DECLARATIONS TO REAL.
C
C   FUNCTION- ADDS THE VALUE OF CONSTANT TO EACH ELEMENT OF THE VECTOR,
C             REPLACING THE ORIGINAL VALUES
C
C   CALLING SEQUENCE PARAMETERS-
C
C   NAME   TYPE  I/O    DESCRIPTION
C
C   VECR   REAL  I/O    REAL VECTOR OF DIMENSION NVEC
C   NVEC   INT   I      NUMBER OF ELEMENTS IN VECR
C   CONST  REAL  I      REAL CONSTANT
C
C***********************************************************************
C
      INTEGER  NVEC
      REAL     CONST, VECR(NVEC)
C
      INCLUDE 'SPVAL'
C
      DO 10 J = 1,NVEC
        IF (VECR(J) .NE. R4SPV)   VECR(J) = VECR(J) + CONST
   10 CONTINUE
C
      RETURN
      END
